==> 3.6.8.zip: source-immo/views/list/listings/raw.php <==
<?php 
//Debug::write($configs);
extract( shortcode_atts(
    array(
        'side_scroll' => false
    ), $sc_atts )
);
unset($sc_atts['side_scroll']);

$global_container_classes = array('si', 'si-list-of-item','raw-layout', "si-list-of-{$configs->type}",$configs->list_layout->scope_class);
$global_container_attr = array();

global $dictionary;

$meta = SourceImmoApi::get_list_meta($configs);


$dictionary = new SourceImmoDictionary($meta->dictionary);
$data = SourceImmoApi::get_data($configs, ["limit" => $configs->limit, "show_list_meta" => false]);

$resultView = new SourceImmoListingsResult($data);

$list_styles = array();
$list_attrs = [];

?>
<div class="<?php echo(implode(' ' , $global_container_classes)) ?>" 
    style="<?php echo(implode(';', $list_styles)) ?>"  
    <?php echo(implode(' ', $list_attrs)) ?>
    si-lazy-load>
    <?php
    SourceImmo::staticDataController($configs, $resultView->listings);

    
    if(is_array($resultView->listings) && !empty($resultView->listings)){
        
        echo('<div class="si-list">');
            $itemIndex = 0;
            foreach ($resultView->listings as $item) {
                $cityCode = (isset($item->location->city_code)) ? $item->location->city_code : 'NA';

                echo('<div class="item-' . $item->ref_number . ' city-' . sanitize_title($cityCode) . '" style="--si-item-index:' . $itemIndex . '">');
                SourceImmo::view("list/{$configs->type}/direct/item-raw", 
                    array("configs" => $configs, "item" => $item, "dictionary"=> $dictionary));
                echo('</div>');

                $itemIndex++;
            }
        
        echo('</div>');
    }
    ?>
</div>

==> 3.7.0.zip: source-immo/views/list/listings/raw.php <==
<?php 
//Debug::write($configs);
extract( shortcode_atts(
    array(
        'side_scroll' => false
    ), $sc_atts )
);
unset($sc_atts['side_scroll']);

$global_container_classes = array('si', 'si-list-of-item','raw-layout', "si-list-of-{$configs->type}",$configs->list_layout->scope_class);
$global_container_attr = array();

global $dictionary;

if($dictionary == null){
    $meta = SourceImmoApi::get_list_meta($configs);
    $dictionary = new SourceImmoDictionary($meta->dictionary);
}

$data = SourceImmoApi::get_data($configs, ["limit" => $configs->limit, "show_list_meta" => false]);

$resultView = new SourceImmoListingsResult($data);

$list_styles = array();
$list_attrs = [];

?>
<div class="<?php echo(implode(' ' , $global_container_classes)) ?>" 
    style="<?php echo(implode(';', $list_styles)) ?>"  
    <?php echo(implode(' ', $list_attrs)) ?>
    si-lazy-load>
    <?php
    SourceImmo::staticDataController($configs, $resultView->listings);

    
    if(is_array($resultView->listings) && !empty($resultView->listings)){
        
        echo('<div class="si-list si-list-of-' . count($resultView->listings) . '">');
            $itemIndex = 0;
            foreach ($resultView->listings as $item) {
                $cityCode = (isset($item->location->city_code)) ? $item->location->city_code : 'NA';

                echo('<div class="item-' . $item->ref_number . ' city-' . sanitize_title($cityCode) . '" style="--si-item-index:' . $itemIndex . '">');
                SourceImmo::view("list/{$configs->type}/direct/item-raw", 
                    array("configs" => $configs, "item" => $item, "dictionary"=> $dictionary));
                echo('</div>');

                $itemIndex++;
            }
        
        echo('</div>');
    }
    ?>
</div>
